@@ -108,11 +108,10 @@ class QueryManager:
 
         try:
             context_overwrite_json = CONTEXT_OVERWRITE_CLASS_FILE
-            self.context_overwrite = json.loads(
-                self.read_context(context_dir /
-                                  context_overwrite_json))[CONTEXT_KEY]
+            context_overwrite_path = context_dir / context_overwrite_json
+            self.context_overwrite = json.loads(self.read_context(context_overwrite_path))[CONTEXT_KEY]
         except FileNotFoundError as e:
-            self.context_overwrite = None
+            self.context_overwrite = {}
 
         remove_jsonld_key(tmp_context_class, CONTEXT_TYPE_KEY)
         remove_jsonld_key(tmp_context_class, CONTEXT_ID_KEY)
@@ -491,6 +490,7 @@ class QueryManager:
 
         # Context (returned by the endpoint) does not contain information about the classes
         # so we must add it to the frame
+        self.overwrite_endpoint_context(frame["@context"])
         frame["@context"] = {**self.class_context, **frame["@context"]}
 
         framed = jsonld.frame(
